@@ -12,7 +12,7 @@ use 5.010;
 #   $ws->send($data);
 #   $ws->close();
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 use Scalar::Util ();
 use Hypersonic::Protocol::WebSocket;
@@ -1019,7 +1019,7 @@ sub gen_xs_process_data {
             ->line('XPUSHs(&PL_sv_undef);')
           ->endif
           ->line('PUTBACK;')
-          ->line('count = call_method("parse_close", G_LIST);')
+          ->line('count = call_method("parse_close", G_ARRAY);')
           ->line('SPAGAIN;')
           ->blank
           ->line('SV* reason_sv = &PL_sv_undef;')
